@@ -39,6 +39,7 @@
 #include <arpa/inet.h>
 #include <signal.h>
 #include <string.h>
+#include <stdlib.h>
 
 
 #include "common.h"
@@ -371,11 +372,13 @@ static void clear_query_buffer(DictData *dd)
 
 static void append_web_search_link(DictData *dd, gboolean prepend_whitespace)
 {
+	gchar *label, *text;
+
 	if (dd->web_url == NULL || dd->mode_in_use != DICTMODE_DICT)
 		return;
 
-	gchar *label = _(dict_prefs_get_web_url_label(dd));
-	gchar *text = g_strdup_printf(
+	label = _(dict_prefs_get_web_url_label(dd));
+	text = g_strdup_printf(
 		/* for translators: the first wildcard is the search term, the second wildcard
 			* is the name of the preferred web search engine */
 		_("Search \"%s\" using \"%s\""),
@@ -394,8 +397,9 @@ static void append_web_search_link(DictData *dd, gboolean prepend_whitespace)
 }
 
 
-static gboolean process_server_response(DictData *dd)
+static gboolean process_server_response(gpointer user_data)
 {
+	DictData *dd = user_data;
 	gint max_lines, i;
 	gint defs_found = 0;
 	gchar *answer, *tmp;
@@ -617,7 +621,7 @@ static gpointer ask_server(DictData *dd)
 	if ((fd = open_socket(dd->server, dd->port)) == -1)
 	{
 		dd->query_status = NO_CONNECTION;
-		g_idle_add((GSourceFunc) process_server_response, dd);
+		g_idle_add(process_server_response, dd);
 		g_thread_exit(NULL);
 		return NULL;
 	}
@@ -647,7 +651,7 @@ static gpointer ask_server(DictData *dd)
 
 	dd->query_is_running = FALSE;
 	/* delegate parsing the response and related GUI stuff to GTK's main thread through the main loop */
-	g_idle_add((GSourceFunc) process_server_response, dd);
+	g_idle_add(process_server_response, dd);
 
 	g_thread_exit(NULL);
 	return NULL;
@@ -667,8 +671,10 @@ static void dictd_init(void)
 
 	if (G_UNLIKELY(! initialized))
 	{
-		siginterrupt(SIGALRM, 1);
-		signal(SIGALRM, signal_cb);
+		struct sigaction action;
+		action.sa_handler = &signal_cb;
+		action.sa_flags = SA_RESTART;
+		sigaction(SIGALRM, &action, NULL);
 
 		initialized = TRUE;
 	}
@@ -770,7 +776,7 @@ void dict_dictd_get_information(GtkWidget *button, DictData *dd)
 	gtk_window_set_default_size(GTK_WINDOW(dialog), 550, 400);
 	gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_CLOSE);
 
-	text = g_strconcat("<tt>", buffer, "</tt>", NULL);
+	text = g_markup_printf_escaped("<tt>%s</tt>", buffer);
 	label = gtk_label_new(text);
 	gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
 	gtk_widget_set_vexpand(label, TRUE);
